[![Coverage Status](https://coveralls.io/repos/github/moj-analytical-services/dataengineeringutils3/badge.svg?branch=master)](https://coveralls.io/github/moj-analytical-services/dataengineeringutils3?branch=master)

# Data engineering utils - Python 3

Fully unit tested utility functions for data engineering. Python 3 only.  


## Installation

```bash
pip install dataengineeringutils3
```


## Testing

```bash
pytest --cov-report term-missing --cov=dataengineeringutils3 tests/
```
